@@ -101,22 +101,25 @@ def auto_tag_pretrained_entities(
     sample_pretrained_entities, count = get_entity_list_from_remote(
         entity_type=PRE_TRAINED, language=language, authtoken=authtoken
     )
-    all_pretrained_entities, _ = get_entity_list_from_remote(
-        entity_type=PRE_TRAINED,
-        language=language,
-        page_number=1,
-        page_size=count,
-        authtoken=authtoken,
-    )
-    all_pretrained_entity_names = {
-        entity[ENTITY]: entity[ENTITY] for entity in all_pretrained_entities
-    }
-    for example in data:
-        entities = example.get(ENTITIES, [])
-        for entity_value in entities:
-            if entity_value[ENTITY] in all_pretrained_entity_names:
-                entity_value[ENTITY] = all_pretrained_entity_names[entity_value[ENTITY]]
-                entity_value[ENTITY_TYPE] = PRE_TRAINED
+    if count:
+        all_pretrained_entities, _ = get_entity_list_from_remote(
+            entity_type=PRE_TRAINED,
+            language=language,
+            page_number=1,
+            page_size=count,
+            authtoken=authtoken,
+        )
+        all_pretrained_entity_names = {
+            entity[ENTITY]: entity[ENTITY] for entity in all_pretrained_entities
+        }
+        for example in data:
+            entities = example.get(ENTITIES, [])
+            for entity_value in entities:
+                if entity_value[ENTITY] in all_pretrained_entity_names:
+                    entity_value[ENTITY] = all_pretrained_entity_names[
+                        entity_value[ENTITY]
+                    ]
+                    entity_value[ENTITY_TYPE] = PRE_TRAINED
     return data
 
 
